@@ -4,7 +4,7 @@
 <context>
     <name>FeatherNotes::AboutDialog</name>
     <message>
-        <location filename="../../about.ui" line="169"/>
+        <location filename="../../about.ui" line="171"/>
         <source>License</source>
         <translation>Llicència</translation>
     </message>
@@ -212,7 +212,7 @@
     </message>
     <message>
         <location filename="../../fn.ui" line="534"/>
-        <location filename="../../fn.cpp" line="991"/>
+        <location filename="../../fn.cpp" line="1018"/>
         <source>Save</source>
         <translation>Desa</translation>
     </message>
@@ -223,7 +223,7 @@
     </message>
     <message>
         <location filename="../../fn.ui" line="542"/>
-        <location filename="../../fn.cpp" line="646"/>
+        <location filename="../../fn.cpp" line="678"/>
         <source>&amp;Open</source>
         <translation>&amp;Obre</translation>
     </message>
@@ -394,7 +394,7 @@
     </message>
     <message>
         <location filename="../../fn.ui" line="710"/>
-        <location filename="../../fn.cpp" line="645"/>
+        <location filename="../../fn.cpp" line="677"/>
         <source>&amp;New Note</source>
         <translation>&amp;Nota nova</translation>
     </message>
@@ -435,7 +435,7 @@
     </message>
     <message>
         <location filename="../../fn.ui" line="756"/>
-        <location filename="../../fn.cpp" line="648"/>
+        <location filename="../../fn.cpp" line="680"/>
         <source>&amp;Quit</source>
         <translation>&amp;Surt</translation>
     </message>
@@ -496,7 +496,7 @@
     </message>
     <message>
         <location filename="../../fn.ui" line="822"/>
-        <location filename="../../fn.cpp" line="4390"/>
+        <location filename="../../fn.cpp" line="4414"/>
         <source>Embed Image</source>
         <translation>Incrusta la imatge</translation>
     </message>
@@ -702,7 +702,7 @@
     </message>
     <message>
         <location filename="../../fn.ui" line="1065"/>
-        <location filename="../../fn.cpp" line="2191"/>
+        <location filename="../../fn.cpp" line="2217"/>
         <source>&amp;Right</source>
         <translation>&amp;Dreta</translation>
     </message>
@@ -718,7 +718,7 @@
     </message>
     <message>
         <location filename="../../fn.ui" line="1082"/>
-        <location filename="../../fn.cpp" line="2185"/>
+        <location filename="../../fn.cpp" line="2211"/>
         <source>&amp;Left</source>
         <translation>&amp;Esquerra</translation>
     </message>
@@ -991,434 +991,445 @@
         <translation>&amp;Neteja</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="2975"/>
+        <location filename="../../fn.cpp" line="3001"/>
         <source>Node Icon</source>
         <translation>Icona del node</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="642"/>
+        <location filename="../../fn.cpp" line="674"/>
         <source>&amp;Raise/Hide</source>
         <translation>&amp;Apuja/amaga</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="887"/>
+        <location filename="../../fn.cpp" line="914"/>
         <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;New note?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
         <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Nota nova?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="888"/>
+        <location filename="../../fn.cpp" line="915"/>
         <source>&lt;center&gt;&lt;i&gt;Do you really want to leave this document&lt;/i&gt;&lt;/center&gt;
 &lt;center&gt;&lt;i&gt;and create an empty one?&lt;/i&gt;&lt;/center&gt;</source>
         <translation>&lt;center&gt;&lt;i&gt;Realment voleu sortir d&apos;aquest document&lt;/i&gt;&lt;/center&gt;
 &lt;center&gt;&lt;i&gt;i crear-ne un de buit?t?&lt;/i&gt;&lt;/center&gt;</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="891"/>
-        <location filename="../../fn.cpp" line="2806"/>
-        <location filename="../../fn.cpp" line="4750"/>
+        <location filename="../../fn.cpp" line="918"/>
+        <location filename="../../fn.cpp" line="2832"/>
+        <location filename="../../fn.cpp" line="4777"/>
         <source>Yes</source>
         <translation>Sí</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="892"/>
-        <location filename="../../fn.cpp" line="2807"/>
-        <location filename="../../fn.cpp" line="4751"/>
+        <location filename="../../fn.cpp" line="919"/>
+        <location filename="../../fn.cpp" line="2833"/>
+        <location filename="../../fn.cpp" line="4778"/>
         <source>No</source>
         <translation>No</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="983"/>
+        <location filename="../../fn.cpp" line="1010"/>
         <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Save changes?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
         <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Voleu desar els canvis?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="985"/>
+        <location filename="../../fn.cpp" line="1012"/>
         <source>&lt;center&gt;&lt;i&gt;The document has been modified.&lt;/i&gt;&lt;/center&gt;</source>
         <translation>&lt;center&gt;&lt;i&gt;S&apos;ha modificat el document.&lt;/i&gt;&lt;/center&gt;</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="987"/>
+        <location filename="../../fn.cpp" line="1014"/>
         <source>&lt;center&gt;&lt;i&gt;The document has been removed.&lt;/i&gt;&lt;/center&gt;</source>
         <translation>&lt;center&gt;&lt;i&gt;S&apos;ha eliminat el document.&lt;/i&gt;&lt;/center&gt;</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="992"/>
+        <location filename="../../fn.cpp" line="1019"/>
         <source>Discard changes</source>
         <translation>Descarta els canvis</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="993"/>
-        <location filename="../../fn.cpp" line="2924"/>
-        <location filename="../../fn.cpp" line="3018"/>
-        <location filename="../../fn.cpp" line="3293"/>
-        <location filename="../../fn.cpp" line="4329"/>
-        <location filename="../../fn.cpp" line="4414"/>
-        <location filename="../../fn.cpp" line="4589"/>
-        <location filename="../../fn.cpp" line="4852"/>
-        <location filename="../../fn.cpp" line="5800"/>
-        <location filename="../../fn.cpp" line="6079"/>
-        <location filename="../../fn.cpp" line="6177"/>
+        <location filename="../../fn.cpp" line="1020"/>
+        <location filename="../../fn.cpp" line="2950"/>
+        <location filename="../../fn.cpp" line="3044"/>
+        <location filename="../../fn.cpp" line="3317"/>
+        <location filename="../../fn.cpp" line="4353"/>
+        <location filename="../../fn.cpp" line="4438"/>
+        <location filename="../../fn.cpp" line="4616"/>
+        <location filename="../../fn.cpp" line="4879"/>
+        <location filename="../../fn.cpp" line="5827"/>
+        <location filename="../../fn.cpp" line="6106"/>
+        <location filename="../../fn.cpp" line="6204"/>
         <source>Cancel</source>
         <translation>Cancel·la</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="1457"/>
+        <location filename="../../fn.cpp" line="1484"/>
         <source>Open file...</source>
         <translation>Obre un fitxer...</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="1634"/>
-        <location filename="../../fn.cpp" line="5926"/>
+        <location filename="../../fn.cpp" line="1661"/>
+        <location filename="../../fn.cpp" line="5953"/>
         <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be saved!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
         <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;No es pot desar!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="3589"/>
+        <location filename="../../fn.cpp" line="3613"/>
         <source>Close</source>
         <translation>Tanca</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="1734"/>
-        <location filename="../../fn.cpp" line="1757"/>
+        <location filename="../../fn.cpp" line="1761"/>
+        <location filename="../../fn.cpp" line="1784"/>
         <source>Save As...</source>
         <translation>Desa com...</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="2803"/>
+        <location filename="../../fn.cpp" line="1486"/>
+        <location filename="../../fn.cpp" line="1763"/>
+        <location filename="../../fn.cpp" line="1786"/>
+        <source>FeatherNotes documents</source>
+        <translation>Documents de FeatherNotes</translation>
+    </message>
+    <message>
+        <location filename="../../fn.cpp" line="1486"/>
+        <location filename="../../fn.cpp" line="1763"/>
+        <location filename="../../fn.cpp" line="1786"/>
+        <location filename="../../fn.cpp" line="3033"/>
+        <location filename="../../fn.cpp" line="4537"/>
+        <location filename="../../fn.cpp" line="4808"/>
+        <source>All Files</source>
+        <translation>Tots els fitxers</translation>
+    </message>
+    <message>
+        <location filename="../../fn.cpp" line="2829"/>
         <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Delete this node?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
         <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Voleu suprimir aquest node?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="2804"/>
+        <location filename="../../fn.cpp" line="2830"/>
         <source>&lt;center&gt;&lt;b&gt;&lt;i&gt;Warning!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
 &lt;center&gt;This action cannot be undone.&lt;/center&gt;</source>
         <translation>&lt;center&gt;&lt;b&gt;&lt;i&gt;Avís!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
 &lt;center&gt;Aquesta acció no es pot desfer.&lt;/center&gt;</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="2910"/>
+        <location filename="../../fn.cpp" line="2936"/>
         <source>Tags</source>
         <translation>Etiquetes</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="2925"/>
-        <location filename="../../fn.cpp" line="3019"/>
-        <location filename="../../fn.cpp" line="3294"/>
-        <location filename="../../fn.cpp" line="4331"/>
-        <location filename="../../fn.cpp" line="4415"/>
-        <location filename="../../fn.cpp" line="4590"/>
-        <location filename="../../fn.cpp" line="4853"/>
-        <location filename="../../fn.cpp" line="5802"/>
-        <location filename="../../fn.cpp" line="6080"/>
-        <location filename="../../fn.cpp" line="6178"/>
+        <location filename="../../fn.cpp" line="2951"/>
+        <location filename="../../fn.cpp" line="3045"/>
+        <location filename="../../fn.cpp" line="3318"/>
+        <location filename="../../fn.cpp" line="4355"/>
+        <location filename="../../fn.cpp" line="4439"/>
+        <location filename="../../fn.cpp" line="4617"/>
+        <location filename="../../fn.cpp" line="4880"/>
+        <location filename="../../fn.cpp" line="5829"/>
+        <location filename="../../fn.cpp" line="6107"/>
+        <location filename="../../fn.cpp" line="6205"/>
         <source>OK</source>
         <translation>D&apos;acord</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="3099"/>
-        <location filename="../../fn.cpp" line="3132"/>
+        <location filename="../../fn.cpp" line="3033"/>
+        <location filename="../../fn.cpp" line="4537"/>
+        <location filename="../../fn.cpp" line="4808"/>
+        <source>Image Files</source>
+        <translation>Fitxers d&apos;imatge</translation>
+    </message>
+    <message>
+        <location filename="../../fn.cpp" line="3125"/>
+        <location filename="../../fn.cpp" line="3158"/>
         <source>&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</source>
         <translation>&lt;b&gt;Nodes principals:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;Tots els nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="3105"/>
-        <location filename="../../fn.cpp" line="3138"/>
+        <location filename="../../fn.cpp" line="3131"/>
+        <location filename="../../fn.cpp" line="3164"/>
         <source>&lt;b&gt;Note:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</source>
         <translation>&lt;b&gt;Nota:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;Nodes principals:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;Tots els nodes:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="3576"/>
+        <location filename="../../fn.cpp" line="3600"/>
         <source>%1 Matches</source>
         <translation>%1 Coincidències</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="3578"/>
+        <location filename="../../fn.cpp" line="3602"/>
         <source>One Match</source>
         <translation>Una coincidència</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="3580"/>
-        <location filename="../../fn.cpp" line="3947"/>
+        <location filename="../../fn.cpp" line="3604"/>
+        <location filename="../../fn.cpp" line="3971"/>
         <source>No Match</source>
         <translation>Sense coincidència</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="3746"/>
-        <location filename="../../fn.cpp" line="3799"/>
+        <location filename="../../fn.cpp" line="3770"/>
+        <location filename="../../fn.cpp" line="3823"/>
         <source>Replacement</source>
         <translation>Substitució</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="4054"/>
+        <location filename="../../fn.cpp" line="4078"/>
         <source>No Replacement</source>
         <translation>Sense substitució</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="4056"/>
+        <location filename="../../fn.cpp" line="4080"/>
         <source>One Replacement</source>
         <translation>Una substitució</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="4059"/>
+        <location filename="../../fn.cpp" line="4083"/>
         <source>%1 Replacements</source>
         <translation>%1 Substitucions</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="4317"/>
+        <location filename="../../fn.cpp" line="4341"/>
         <source>Insert Link</source>
         <translation>Insereix un enllaç</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="2983"/>
-        <location filename="../../fn.cpp" line="4399"/>
+        <location filename="../../fn.cpp" line="6050"/>
+        <source>HTML Files</source>
+        <translation>Fitxers HTML</translation>
+    </message>
+    <message>
+        <location filename="../../fn.cpp" line="3009"/>
+        <location filename="../../fn.cpp" line="4423"/>
         <source>Image path</source>
         <translation>Camí a la imatge</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="2987"/>
-        <location filename="../../fn.cpp" line="4403"/>
+        <location filename="../../fn.cpp" line="3013"/>
+        <location filename="../../fn.cpp" line="4427"/>
         <source>Open image</source>
         <translation>Obre la imatge</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="4411"/>
-        <location filename="../../fn.cpp" line="4586"/>
+        <location filename="../../fn.cpp" line="4435"/>
+        <location filename="../../fn.cpp" line="4613"/>
         <source>Scaling percentage</source>
         <translation>Percentatge d&apos;escala</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="3005"/>
-        <location filename="../../fn.cpp" line="4508"/>
+        <location filename="../../fn.cpp" line="3031"/>
+        <location filename="../../fn.cpp" line="4535"/>
         <source>Open Image...</source>
         <translation>Obre la imatge...</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="617"/>
+        <location filename="../../fn.cpp" line="649"/>
         <source>System tray is not available.
 Please disable tray in Preferences.</source>
         <translation>La safata del sistema no està disponible
 Desactiveu la safata en Preferències.</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="938"/>
+        <location filename="../../fn.cpp" line="965"/>
         <source>New Node</source>
         <translation>Nou node</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="1459"/>
-        <location filename="../../fn.cpp" line="1736"/>
-        <location filename="../../fn.cpp" line="1759"/>
-        <source>FeatherNotes documents (*.fnx);;All Files (*)</source>
-        <translation>Documents de FeatherNotes (*.fnx);;Tots els fitxers (*)</translation>
-    </message>
-    <message>
-        <location filename="../../fn.cpp" line="1635"/>
+        <location filename="../../fn.cpp" line="1662"/>
         <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be opened!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
         <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;No es pot obrir!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="1716"/>
-        <location filename="../../fn.cpp" line="5641"/>
-        <location filename="../../fn.cpp" line="5650"/>
-        <location filename="../../fn.cpp" line="5789"/>
-        <location filename="../../fn.cpp" line="5980"/>
-        <location filename="../../fn.cpp" line="5989"/>
+        <location filename="../../fn.cpp" line="1743"/>
+        <location filename="../../fn.cpp" line="5668"/>
+        <location filename="../../fn.cpp" line="5677"/>
+        <location filename="../../fn.cpp" line="5816"/>
+        <location filename="../../fn.cpp" line="6007"/>
         <location filename="../../fn.cpp" line="6016"/>
+        <location filename="../../fn.cpp" line="6043"/>
         <source>Untitled</source>
         <translation>Sense títol</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="2184"/>
+        <location filename="../../fn.cpp" line="2210"/>
         <source>Align Table</source>
         <translation>Alinea la taula</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="2197"/>
+        <location filename="../../fn.cpp" line="2223"/>
         <source>&amp;Center</source>
         <translation>&amp;Centrar</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="2636"/>
+        <location filename="../../fn.cpp" line="2662"/>
         <source>Select Text Color</source>
         <translation>Selecciona el color del text</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="2668"/>
+        <location filename="../../fn.cpp" line="2694"/>
         <source>Select Background Color</source>
         <translation>Selecciona el color de fons</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="2802"/>
+        <location filename="../../fn.cpp" line="2828"/>
         <source>Deletion</source>
         <translation>Supressió</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="2920"/>
+        <location filename="../../fn.cpp" line="2946"/>
         <source>Tag(s) for this node</source>
         <translation>Etiqueta(es) d&apos;aquest node</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="3007"/>
-        <location filename="../../fn.cpp" line="4510"/>
-        <source>Image Files (*.svg *.png *.jpg *.jpeg *.bmp *.gif);;All Files (*)</source>
-        <translation>Fitxers d&apos;imatge (*.svg *.png *.jpg *.jpeg *.bmp *.gif);;All Files (*)</translation>
-    </message>
-    <message>
-        <location filename="../../fn.cpp" line="3176"/>
+        <location filename="../../fn.cpp" line="3202"/>
         <source>Select Document Font</source>
         <translation>Seleccioneu el tipus de lletra del document</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="3240"/>
+        <location filename="../../fn.cpp" line="3264"/>
         <source>Select Node Font</source>
         <translation>Seleccioneu el tipus de lletra del node</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="3265"/>
+        <location filename="../../fn.cpp" line="3289"/>
         <source>Set Document Colors</source>
         <translation>Estableix els colors del document</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="3275"/>
+        <location filename="../../fn.cpp" line="3299"/>
         <source>These colors will be applied to new nodes.&lt;br&gt;They may or may not affect existing nodes&lt;br&gt;but document reopening is recommended.</source>
         <translation>Aquests colors s&apos;aplicaran als nodes nous.&lt;br&gt;Poden o no afectar els nodes existents&lt;br&gt;però es recomana tornar a obrir el document.</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="3278"/>
+        <location filename="../../fn.cpp" line="3302"/>
         <source>Background color:</source>
         <translation>Color de fons:</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="3284"/>
+        <location filename="../../fn.cpp" line="3308"/>
         <source>Text color:</source>
         <translation>Color del text:</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="4064"/>
+        <location filename="../../fn.cpp" line="4088"/>
         <source>The first 1000 replacements are highlighted.</source>
         <translation>Es ressalten les primeres 1.000 substitucions.</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="4406"/>
-        <location filename="../../fn.cpp" line="4582"/>
+        <location filename="../../fn.cpp" line="4430"/>
+        <location filename="../../fn.cpp" line="4609"/>
         <source>Scale to</source>
         <translation>Escala a</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="4410"/>
-        <location filename="../../fn.cpp" line="4585"/>
+        <location filename="../../fn.cpp" line="4434"/>
+        <location filename="../../fn.cpp" line="4612"/>
         <source>%</source>
         <translation>%</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="4576"/>
+        <location filename="../../fn.cpp" line="4603"/>
         <source>Scale Image(s)</source>
         <translation>Escala les imatges</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="4713"/>
+        <location filename="../../fn.cpp" line="4740"/>
         <source>untitled</source>
         <translation>sense títol</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="4745"/>
+        <location filename="../../fn.cpp" line="4772"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="4746"/>
+        <location filename="../../fn.cpp" line="4773"/>
         <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Image cannot be saved! Retry?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
         <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;La imatge no es pot desar! Vol tornar a provar-ho?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="4747"/>
+        <location filename="../../fn.cpp" line="4774"/>
         <source>&lt;center&gt;Maybe you did not choose a proper extension&lt;/center&gt;
 &lt;center&gt;or do not have write permission.&lt;/center&gt;&lt;p&gt;&lt;/p&gt;</source>
         <translation>&lt;center&gt;Potser no heu triat una extensió adequada&lt;/center&gt;
 &lt;center&gt;o no té permisos d&apos;escriptura.&lt;/center&gt;&lt;p&gt;&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="4779"/>
+        <location filename="../../fn.cpp" line="4806"/>
         <source>Save Image As...</source>
         <translation>Desa la imatge com a...</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="4781"/>
-        <source>Image Files (*.png *.jpg *.jpeg *.bmp);;All Files (*)</source>
-        <translation>Fitxers d&apos;imatge (*.png *.jpg *.jpeg *.bmp);;Tots els fitxers (*)</translation>
-    </message>
-    <message>
-        <location filename="../../fn.cpp" line="4834"/>
+        <location filename="../../fn.cpp" line="4861"/>
         <source>Insert Table</source>
         <translation>Insereix una taula</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="4840"/>
+        <location filename="../../fn.cpp" line="4867"/>
         <source>Rows:</source>
         <translation>Files:</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="4846"/>
+        <location filename="../../fn.cpp" line="4873"/>
         <source>Columns:</source>
         <translation>Columnes:</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="5730"/>
+        <location filename="../../fn.cpp" line="5757"/>
         <source>Print Document</source>
         <translation>Imprimeix el document</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="5736"/>
+        <location filename="../../fn.cpp" line="5763"/>
         <source>Printing completed.</source>
         <translation>Impressió completada.</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="5738"/>
+        <location filename="../../fn.cpp" line="5765"/>
         <source>Printing in progress...</source>
         <translation>Impresió en curs...</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="5757"/>
+        <location filename="../../fn.cpp" line="5784"/>
         <source>Export HTML</source>
         <translation>Exporta HTML</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="5762"/>
+        <location filename="../../fn.cpp" line="5789"/>
         <source>Export:</source>
         <translation>Exporta:</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="5763"/>
+        <location filename="../../fn.cpp" line="5790"/>
         <source>&amp;Current node</source>
         <translation>&amp;Node actual</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="5765"/>
+        <location filename="../../fn.cpp" line="5792"/>
         <source>With all &amp;sub-nodes</source>
         <translation>Amb tots els &amp;subnodes</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="5766"/>
+        <location filename="../../fn.cpp" line="5793"/>
         <source>&amp;All nodes</source>
         <translation>&amp;Tots els nodes</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="5778"/>
+        <location filename="../../fn.cpp" line="5805"/>
         <source>Output file:</source>
         <translation>Fitxer de sortida:</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="5797"/>
+        <location filename="../../fn.cpp" line="5824"/>
         <source>Select path</source>
         <translation>Seleccioneu el camí</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="5838"/>
+        <location filename="../../fn.cpp" line="5865"/>
         <source>Question</source>
         <translation>Pregunta</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="5839"/>
+        <location filename="../../fn.cpp" line="5866"/>
         <source>The file already exists.
 Do you want to replace it?
 </source>
@@ -1427,106 +1438,101 @@ Voleu reemplaçar-lo?
 </translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="6021"/>
+        <location filename="../../fn.cpp" line="6048"/>
         <source>Save HTML As...</source>
         <translation>Desa l&apos;HTML com a...</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="6023"/>
-        <source>HTML Files (*.html *.htm)</source>
-        <translation>Fitxers HTML (*.html *.htm)</translation>
-    </message>
-    <message>
-        <location filename="../../fn.cpp" line="6047"/>
+        <location filename="../../fn.cpp" line="6074"/>
         <source>Set Password</source>
         <translation>Estableix la contrasenya</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="6056"/>
+        <location filename="../../fn.cpp" line="6083"/>
         <source>Type password</source>
         <translation>Escriu la contrasenya</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="6068"/>
+        <location filename="../../fn.cpp" line="6095"/>
         <source>Retype password</source>
         <translation>Torna a escriure la contrasenya</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="6140"/>
+        <location filename="../../fn.cpp" line="6167"/>
         <source>&lt;center&gt;Passwords were different. Retry!&lt;/center&gt;</source>
         <translation>&lt;center&gt;Les contrasenyes eren diferents. Reintenta!&lt;/center&gt;</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="6160"/>
-        <location filename="../../fn.cpp" line="6168"/>
+        <location filename="../../fn.cpp" line="6187"/>
+        <location filename="../../fn.cpp" line="6195"/>
         <source>Enter Password</source>
         <translation>Introduïu la contrasenya</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="6240"/>
+        <location filename="../../fn.cpp" line="6267"/>
         <source>&lt;center&gt;Wrong password. Retry!&lt;/center&gt;</source>
         <translation>&lt;center&gt;Contrasenya incorrecta. Reintenta!&lt;/center&gt;</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="6282"/>
+        <location filename="../../fn.cpp" line="6309"/>
         <source>A lightweight notes manager</source>
         <translation>Un gestor de notes lleuger</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="6283"/>
+        <location filename="../../fn.cpp" line="6310"/>
         <source>based on Qt</source>
         <translation>basat en Qt</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="6284"/>
+        <location filename="../../fn.cpp" line="6311"/>
         <source>Author</source>
         <translation>Autor</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="6286"/>
-        <location filename="../../fn.cpp" line="6287"/>
+        <location filename="../../fn.cpp" line="6313"/>
+        <location filename="../../fn.cpp" line="6314"/>
         <source>About FeatherNotes</source>
         <translation>Quant a FeatherNotes</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="6286"/>
+        <location filename="../../fn.cpp" line="6313"/>
         <source>Translators</source>
         <translation>Traductors</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="6470"/>
+        <location filename="../../fn.cpp" line="6497"/>
         <source>See Preferences → Text → Spell Checking!</source>
         <translation>Vegeu Preferències → Text → Comprovació ortogràfica.</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="6486"/>
+        <location filename="../../fn.cpp" line="6513"/>
         <source>You need to add a Hunspell dictionary.</source>
         <translation>Heu d&apos;afegir un diccionari Hunspell.</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="6491"/>
+        <location filename="../../fn.cpp" line="6518"/>
         <source>The Hunspell dictionary does not exist.</source>
         <translation>El diccionari Hunspell no existeix.</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="6499"/>
+        <location filename="../../fn.cpp" line="6526"/>
         <source>The Hunspell dictionary is not accompanied by an affix file.</source>
         <translation>El diccionari Hunspell no està acompanyat per un fitxer d&apos;afix.</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="6517"/>
-        <location filename="../../fn.cpp" line="6532"/>
         <location filename="../../fn.cpp" line="6544"/>
+        <location filename="../../fn.cpp" line="6559"/>
+        <location filename="../../fn.cpp" line="6571"/>
         <source>No misspelling from text cursor.</source>
         <translation>No hi ha errors d&apos;ortografia des del cursor de text.</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="6556"/>
+        <location filename="../../fn.cpp" line="6583"/>
         <source>Spell Checking</source>
         <translation>Comprovació ortogràfica</translation>
     </message>
     <message>
-        <location filename="../../fn.cpp" line="6285"/>
+        <location filename="../../fn.cpp" line="6312"/>
         <source>aka.</source>
         <translation>àlies</translation>
     </message>
@@ -1865,8 +1871,8 @@ nom però que acabi amb «.aff».</translation>
     </message>
     <message>
         <location filename="../../pref.cpp" line="649"/>
-        <source>Hunspell Dictionary Files (*.dic)</source>
-        <translation>Fitxers de diccionari Hunspell (*.dic)</translation>
+        <source>Hunspell Dictionary Files</source>
+        <translation>Fitxers de diccionari Hunspell</translation>
     </message>
 </context>
 <context>
